import {
  PrismaClient,
  ReportReason,
  Session,
  Topic,
  User,
} from '@prisma/client';
import {
  seedAvailability,
  seedExperience,
  seedReport,
  seedReportReasons,
  seedReview,
  seedSession,
  seedSocialMedia,
  seedTopic,
  seedUserTopic,
  seedUsers,
  seedBannedAccount,
  seedPayments,
} from './seeds';
const prisma = new PrismaClient();

async function main(prisma: PrismaClient) {
  console.log('🌱 Seeding...');

  const topics: Topic[] = await seedTopic(prisma);
  const users: User[] = await seedUsers(prisma);
  const reportReasons: ReportReason[] = await seedReportReasons(prisma);
  const sessions: Session[] = await seedSession(prisma, users);

  // =======With Relation========
  await seedUserTopic(prisma, users, topics);
  await seedAvailability(prisma, users);
  await seedSocialMedia(prisma, users);
  await seedExperience(prisma, users);
  await seedReview(prisma, users);
  await seedReport(prisma, users, reportReasons);
  await seedBannedAccount(prisma, users);
  await seedPayments(prisma, sessions);
}

main(prisma)
  .then(async () => {
    await prisma.$disconnect();
  })
  .catch(async (e) => {
    console.error(e);
    await prisma.$disconnect();
    process.exit(1);
  });
