import { Injectable } from '@nestjs/common';
import { StreamChat } from 'stream-chat';
import { ConfigService } from '@nestjs/config';

@Injectable()
export class StreamChatService {
  private streamChat: StreamChat;

  constructor(private readonly configService: ConfigService) {
    this.streamChat = new StreamChat(
      this.configService.get<string>('STREAM_API_KEY')!,
      this.configService.get<string>('STREAM_API_SECRET'),
    );
  }

  async connect(userId: string) {
    // await this.streamChat.connectUser(
    //   { id: userId },
    //   this.streamChat.devToken(userId),
    // );

    const {
      users: [user],
    } = await this.streamChat.queryUsers({ id: userId });

    if (user == null) return false;

    const token = this.streamChat.createToken(userId);
    return token;

    // return {
    //   token,
    //   user: { image: user.image },
    // };
  }

  async disconnect(userId: string): Promise<void> {
    await this.streamChat.revokeUserToken(userId, new Date());
  }

  async createUser(userId: string, name: string) {
    const existingUsers = await this.streamChat.queryUsers({ id: userId });

    if (existingUsers?.users?.length > 0) return false;

    return await this.streamChat.upsertUsers([
      {
        id: userId,
        name,
      },
    ]);
  }

  async updateUser(userId: string, name: string, image: string) {
    const existingUsers = await this.streamChat.queryUsers({ id: userId });

    if (existingUsers?.users?.length > 1) return false;

    return await this.streamChat.upsertUsers([
      {
        id: userId,
        name,
        image,
      },
    ]);
  }

  async createChannel(channelId: string): Promise<void> {
    await this.streamChat.channel('messaging', channelId).create();
  }

  async sendMessage(channelId: string, message: string): Promise<void> {
    await this.streamChat
      .channel('messaging', channelId)
      .sendMessage({ text: message });
  }
}
