import { PrismaService } from '@/core/database/prisma.service';
import { Injectable } from '@nestjs/common';

@Injectable()
export class ExperienceRepository {
  constructor(private prisma: PrismaService) {}

  async create(data) {
    const experience = await this.prisma.experience.create({
      data: {
        company: data.company,
        role: data.role,
        description: data.description,
        startDate: data.startDate,
        endDate: data.endDate,
        userId: data.userId,
      },
    });

    return experience;
  }

  async findAllExperiencesByUserId(userId) {
    const experiences = await this.prisma.experience.findMany({
      where: {
        userId: userId,
      },
    });

    return experiences;
  }

  async findExperienceById(id) {
    const experience = await this.prisma.experience.findUnique({
      where: {
        id: id,
      },
    });
    return experience;
  }

  async updateExperienceById(id, data) {
    const experience = await this.prisma.experience.update({
      where: {
        id: id,
      },
      data: {
        company: data.company,
        role: data.role,
        description: data.description,
        startDate: data.startDate,
        endDate: data.endDate,
      },
    });

    return experience;
  }

  async deleteExperienceById(id) {
    const experience = await this.prisma.experience.delete({
      where: {
        id: id,
      },
    });

    return experience;
  }
}
