import { Injectable } from '@nestjs/common';
import { Availability } from '.prisma/client';
import { faker } from '@faker-js/faker';
import { PrismaClient } from '@prisma/client';
import { UserFactory } from './user.factory';
import { buildDates } from '../utils';

const weekDays = [
  'Segunda',
  'Terça',
  'Quarta',
  'Quinta',
  'Sexta',
  'Sábado',
  'Domingo',
];

@Injectable()
export class AvailabilityFactory {
  static async create(
    prisma: PrismaClient,
    overrides: Partial<Availability> = {},
  ): Promise<Availability> {
    const availability = await AvailabilityFactory.build(overrides, prisma);
    return await prisma.availability.create({
      data: availability,
    });
  }

  static async build(
    overrides: Partial<Availability> = {},
    prisma: PrismaClient | null = null,
  ) {
    const randomIndex = faker.number.int({
      min: 0,
      max: weekDays.length - 1,
    });

    let userId = overrides.userId || faker.string.uuid();

    if (prisma) {
      userId = (await UserFactory.create(prisma)).id;
    }

    return {
      id: faker.string.uuid(),
      startDate: faker.date.recent(),
      endDate: faker.date.future(),
      weekDay: weekDays[randomIndex],
      userId: userId,
      ...overrides,
    };
  }

  static async buildWithService(
    overrides: Partial<Availability> = {},
    prisma: PrismaClient | null = null,
  ) {
    let userId = overrides.userId || faker.string.uuid();

    if (prisma) {
      userId = (await UserFactory.create(prisma)).id;
    }

    const randomIndex = faker.number.int({
      min: 0,
      max: weekDays.length - 1,
    });

    let startDate: any = faker.number.int({ min: 1, max: 22 });
    let endDate: any = startDate + 1;

    if (startDate < 10) {
      startDate = `0${startDate}`;
    }

    if (endDate < 10) {
      endDate = `0${endDate}`;
    }

    const dates = buildDates(
      {
        startDate: startDate,
        endDate: endDate,
        weekDay: weekDays[randomIndex],
        userId: userId,
      },
      { number: 1, unit: 'month' },
    );

    return dates;
  }
}
