import { Injectable } from '@nestjs/common';
import { Experience } from '.prisma/client';
import { faker } from '@faker-js/faker';
import { PrismaClient } from '@prisma/client';

@Injectable()
export class ExperienceFactory {
  static async create(
    prisma: PrismaClient,
    overrides: Partial<Experience> = {},
  ): Promise<Experience> {
    const experience = ExperienceFactory.build(overrides);
    return await prisma.experience.create({ data: experience });
  }

  static build(overrides: Partial<Experience> = {}) {
    return {
      id: faker.string.uuid(),
      company: faker.company.name(),
      role: faker.person.jobTitle(),
      description: faker.person.jobDescriptor(),
      startDate: faker.date.past(),
      endDate: faker.date.recent(),
      userId: overrides.userId || faker.string.uuid(),
      // Outros campos da experiência
      ...overrides,
    };
  }
}
