import { Injectable } from '@nestjs/common';
import { Review } from '.prisma/client';
import { faker } from '@faker-js/faker';
import { PrismaClient } from '@prisma/client';

@Injectable()
export class ReviewFactory {
  static async create(
    prisma: PrismaClient,
    overrides: Partial<Review> = {},
  ): Promise<Review> {
    const review = ReviewFactory.build(overrides);
    return await prisma.review.create({ data: review });
  }

  static build(overrides: Partial<Review> = {}) {
    const studentId = overrides.studentId || faker.string.uuid();
    const mentorId = overrides.mentorId || faker.string.uuid();

    return {
      id: faker.string.uuid(),
      evaluation: faker.lorem.paragraphs(5),
      mentorId,
      studentId,
      grade: faker.number.int({ min: 1, max: 5 }),
      createdAt: faker.date.recent(),
      // Outros campos do usuário
      ...overrides,
    };
  }
}
