import { Injectable } from '@nestjs/common';
import { UserTopic } from '.prisma/client';
import { faker } from '@faker-js/faker';
import { PrismaClient } from '@prisma/client';
import { TopicFactory } from './topic.factory';

@Injectable()
export class UserTopicFactory {
  static async create(
    prisma: PrismaClient,
    overrides: Partial<UserTopic> = {},
  ): Promise<UserTopic> {
    const userTopic = await UserTopicFactory.build(overrides);
    return await prisma.userTopic.create({ data: userTopic });
  }

  static async build(
    overrides: Partial<UserTopic> = {},
    prisma: PrismaClient | null = null,
  ) {
    let topicId = overrides.topicId || faker.string.uuid();
    const userId = overrides.userId || faker.string.uuid();

    if (prisma) {
      const topic = await TopicFactory.create(prisma);
      topicId = topic.id;
    }

    return {
      id: faker.string.uuid(),
      price: faker.number.float({ min: 10, max: 100, precision: 0.01 }),
      userId,
      topicId,
      // Outros campos de UserTopic
      ...overrides,
    };
  }
}
