import { Injectable } from '@nestjs/common';
import { User } from '.prisma/client';
import { faker } from '@faker-js/faker';
import { PrismaClient } from '@prisma/client';
import { Password } from '../auth/password';

@Injectable()
export class UserFactory {
  static async create(
    prisma: PrismaClient,
    overrides: Partial<User> = {},
  ): Promise<User> {
    const user = await UserFactory.build(overrides);
    return await prisma.user.create({ data: user });
  }

  static async build(overrides: Partial<User> = {}) {
    const [salt, password] = await Password.hashPassword(
      overrides?.password || faker.internet.password(),
    );

    return {
      id: overrides?.id || faker.string.uuid(),
      name: overrides?.name || faker.person.fullName(),
      cpf: overrides?.cpf || faker.string.numeric(11),
      email: overrides?.email || faker.internet.email(),
      password,
      salt,
      avatar: overrides?.avatar || faker.image.avatar(),
      abstract: overrides?.abstract || faker.lorem.paragraphs(5),
      isAdmin: overrides?.isAdmin || faker.datatype.boolean(),
      isMentor: overrides?.isMentor || faker.datatype.boolean(),
      score:
        overrides?.score ||
        faker.number.float({ min: 1, max: 5, precision: 0.1 }),
    };
  }
}
