import { Injectable } from '@nestjs/common';
import { PrismaService } from '@/core/database/prisma.service';

@Injectable()
export class PaymentRepository {
  constructor(private prisma: PrismaService) {}

  // ==== 💳 Payments Cards ====
  async listCards() {
    return await this.prisma.paymentCard.findMany();
  }

  async listCardsByUserId(userId: string) {
    return await this.prisma.paymentCard.findMany({
      where: { userId },
    });
  }

  async createCard(data) {
    return await this.prisma.paymentCard.create({ data });
  }

  async getCardById(id: string) {
    return await this.prisma.paymentCard.findUnique({ where: { id } });
  }

  async updateCard(id: string, session) {
    return await this.prisma.paymentCard.update({
      where: { id },
      data: session,
    });
  }

  async deleteCard(id: string) {
    return await this.prisma.paymentCard.delete({
      where: { id },
    });
  }

  // ==== 💰 Transactions ====

  async createTransaction(data) {
    return await this.prisma.paymentTransaction.create({ data });
  }

  async updateTransaction(sessionId, data) {
    return await this.prisma.paymentTransaction.update({
      where: { sessionId },
      data,
    });
  }
}
