import { Injectable } from '@nestjs/common';
import { PrismaService } from '@/core/database/prisma.service';
import { Session } from '.prisma/client';

@Injectable()
export class SessionRepository {
  constructor(private prisma: PrismaService) {}

  async getAll() {
    return await this.prisma.user.findMany();
  }

  async create(data: any) {
    return await this.prisma.session.create({
      data,
    });
  }

  async getById(id) {
    return await this.prisma.session.findUnique({
      where: {
        id: id,
      },
    });
  }

  async update(id: string, session: Partial<Session>) {
    return await this.prisma.session.update({
      where: {
        id: id,
      },
      data: session,
    });
  }

  async delete(id) {
    return await this.prisma.session.delete({
      where: {
        id: id,
      },
    });
  }

  async listByUserId(userId: string) {
    return await this.prisma.session.findMany({
      where: {
        OR: [{ studentId: userId }, { mentorId: userId }],
      },
      orderBy: {
        createdAt: 'desc',
      },
      include: {
        student: {
          select: {
            name: true,
            avatar: true,
          },
        },
        mentor: {
          select: {
            name: true,
            avatar: true,
          },
        },
        userTopic: {
          select: {
            topic: {
              select: {
                name: true,
              },
            },
          },
        },
      },
    });
  }
}
