import { Injectable } from '@nestjs/common';
import { PrismaService } from '@/core/database/prisma.service';

@Injectable()
export class SocialMediaRepository {
  constructor(private prisma: PrismaService) {}

  async getAllByUserId(userId: string) {
    return await this.prisma.socialMedia.findMany({
      where: { userId },
    });
  }

  async getAll() {
    return await this.prisma.socialMedia.findMany();
  }

  async create(data) {
    return await this.prisma.socialMedia.create({ data });
  }

  async getById(id) {
    return await this.prisma.socialMedia.findUnique({
      where: { id },
    });
  }

  async update(id, data) {
    return await this.prisma.socialMedia.update({
      where: {
        id: id,
      },
      data,
    });
  }

  async delete(id) {
    return await this.prisma.socialMedia.delete({
      where: {
        id: id,
      },
    });
  }
}
