import { Injectable } from '@nestjs/common';
import { PrismaService } from '@/core/database/prisma.service';

@Injectable()
export class TopicRepository {
  constructor(private prisma: PrismaService) {}

  async getAll() {
    return await this.prisma.topic.findMany({
      where: {
        active: true,
      },
    });
  }

  async create(data) {
    const topic = await this.prisma.topic.create({
      data: {
        name: data.name,
        active: data.active,
      },
    });
    return topic;
  }

  async getTopicById(id) {
    const topic = await this.prisma.topic.findUnique({
      where: {
        id: id,
      },
    });
    return topic;
  }

  async updateTopicById(id, data) {
    return await this.prisma.topic.update({
      where: { id },
      data: {
        name: data.name,
        active: data.active,
      },
    });
  }

  async deleteTopicById(id) {
    return await this.prisma.topic.update({
      where: {
        id: id,
      },
      data: {
        active: false,
      },
    });
  }
}
