import { Injectable } from '@nestjs/common';
import { PrismaService } from '@/core/database/prisma.service';
import { InjectConnection } from 'nest-knexjs';
import { Knex } from 'knex';

@Injectable()
export class UserReportRepository {
  constructor(
    private prisma: PrismaService,
    @InjectConnection() private readonly knex: Knex,
  ) {}

  async listAll() {
    return await this.prisma.report.findMany();
  }

  async listReports() {
    const query = `
    WITH reports AS (
      SELECT
          tr.id,
          tr.description,
          trr.description AS reason,
          tr."createdAt",
          tu1.name AS reported_user_name,
          tu1.id AS reported_user_id,
          tu2.name AS reporting_user_name,
          tu2.id AS reporting_user_id,
          '' AS start_ban, -- Text
          '' AS end_ban,   -- Text
          false AS is_banned
      FROM
          "tbReport" tr
      JOIN "tbReportReason" trr ON
          tr."reportReasonId" = trr.id
      JOIN "tbUser" tu1 ON
          tr."reportedUserId" = tu1.id
      JOIN "tbUser" tu2 ON
          tr."reportingUserId" = tu2.id
    ),
      banned_accounts AS (
          SELECT
              tba.id,
              '' AS description,
              tba.reason,
              tba."createdAt",
              tu.name AS reported_user_name,
              tu.id AS reported_user_id,
              '' AS reporting_user_name,
              '' AS reporting_user_id,
              TO_CHAR(tba."startDate", 'YYYY-MM-DD HH24:MI:SS') AS start_ban, -- Convert to Text
              TO_CHAR(tba."endDate", 'YYYY-MM-DD HH24:MI:SS') AS end_ban,     -- Convert to Text
              true AS is_banned
          FROM
              "tbBannedAccount" tba
          JOIN "tbUser" tu ON tba."userId" = tu.id
      )
      SELECT * FROM reports
      UNION ALL
      SELECT * FROM banned_accounts
      ORDER BY "createdAt" DESC;
    `;

    const { rows: reports } = await this.knex.raw(query);
    return reports;
  }

  async listReasons() {
    return await this.prisma.reportReason.findMany();
  }
}
