import { Injectable } from '@nestjs/common';
import { PrismaService } from '@/core/database/prisma.service';

@Injectable()
export class UserTopicRepository {
  constructor(private prisma: PrismaService) {}

  async create(data) {
    const user = await this.prisma.user.findUnique({
      where: { id: data.userId },
    });

    const topic = await this.prisma.topic.findUnique({
      where: { id: data.topicId },
    });

    if (!user || !topic) {
      throw new Error('Usuário ou tópico não encontrado');
    }

    const userTopic = await this.prisma.userTopic.create({
      data: {
        price: data.price,
        userId: data.userId,
        topicId: data.topicId,
      },
    });
    return userTopic;
  }

  async findById(id: string) {
    return await this.prisma.userTopic.findUnique({
      where: { id },
      include: { user: true, topic: true },
    });
  }

  async findByUserId(userId: string) {
    return await this.prisma.userTopic.findMany({
      where: { userId },
      include: { topic: true },
      orderBy: { price: 'asc' },
    });
  }

  async findByTopicId(topicId: string) {
    return await this.prisma.userTopic.findMany({
      where: { topicId },
      include: { user: true, topic: true },
      orderBy: { price: 'asc' },
    });
  }

  async updateById(id: string, data) {
    return await this.prisma.userTopic.update({
      where: { id },
      data,
    });
  }

  async deleteById(id) {
    return await this.prisma.userTopic.delete({
      where: { id },
    });
  }
}
