import dayjs from 'dayjs';
import isSameOrBefore from 'dayjs/plugin/isSameOrBefore';

dayjs.extend(isSameOrBefore);

const weekDays = [
  'Domingo',
  'Segunda',
  'Terça',
  'Quarta',
  'Quinta',
  'Sexta',
  'Sábado',
] as const;

export function buildDates(data, options) {
  const { number = 1, unit = 'year' } = options || {};

  let startDate = dayjs().startOf(unit);
  const endDate = dayjs().add(number, unit);

  const startTime = data.startDate;
  const endTime = data.endDate;

  const recurringEvents: any = [];

  while (startDate.isSameOrBefore(endDate)) {
    // Verifique o dia da semana (0 é domingo, 6 é sábado)
    if (startDate.day() === weekDays.indexOf(data.weekDay)) {
      const event = {
        startDate: new Date(
          `${startDate.format('YYYY-MM-DD')} ${startTime}:00Z`,
        ),
        endDate: new Date(`${startDate.format('YYYY-MM-DD')} ${endTime}:00Z`),
        weekDay: data.weekDay,
        userId: data.userId,
      };

      recurringEvents.push(event);
    }

    // Avance para o próximo domingo
    startDate = startDate.add(1, 'day');
  }

  return recurringEvents;
}
