import { BadRequestException } from '@nestjs/common';
import { ZodError, ZodSchema } from 'zod';
import { fromZodError } from 'zod-validation-error';

export class ZodValidationPipe {
  constructor(private schema: ZodSchema) {}

  transform(value, metadata) {
    try {
      if (metadata.type === 'query' || metadata.type === 'param') return value;
      this.schema.parse(value);
    } catch (error) {
      if (error instanceof ZodError) {
        throw new BadRequestException({
          errors: fromZodError(error),
          message: 'Validation failed',
          status: 400,
        });
      }

      throw new BadRequestException('Validation failed');
    }
    return value;
  }
}
