import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Post,
  Put,
  UsePipes,
} from '@nestjs/common';
import { z } from 'zod';
import { ZodValidationPipe } from '../pipes/zod-validation-pipe';
import { TopicRepository } from '@/core/topic/topic-repository';

const schemaTopic = z.object({
  name: z.string(),
  active: z.boolean(),
});

type TopicBodySchema = z.infer<typeof schemaTopic>;

@Controller('/topics')
export class TopicController {
  constructor(private topicRepository: TopicRepository) {}

  @Get()
  async findAll() {
    return await this.topicRepository.getAll();
  }

  @Get(':id')
  async findOne(@Param('id') id: string) {
    return await this.topicRepository.getTopicById(id);
  }

  @Post()
  @UsePipes(new ZodValidationPipe(schemaTopic))
  async create(@Body() body: TopicBodySchema) {
    return await this.topicRepository.create(body);
  }

  @Put(':id')
  // @UsePipes(new ZodValidationPipe(schemaTopic))
  async update(@Param('id') id: string, @Body() body: TopicBodySchema) {
    console.log(body);
    return await this.topicRepository.updateTopicById(id, body);
  }

  @Delete(':id')
  async delete(@Param('id') id: string) {
    return await this.topicRepository.deleteTopicById(id);
  }
}
