import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Post,
  Put,
  UsePipes,
} from '@nestjs/common';
import { z } from 'zod';
import { ZodValidationPipe } from '../../pipes/zod-validation-pipe';
import { PaymentRepository } from '@/core/session/payment-repository';

const schemaPaymentCard = z.object({
  number: z.string(),
  cvv: z.string(),
  dueDate: z.string(),
  name: z.string(),
  type: z.enum(['credit', 'debit']),
});

type PaymentBodySchema = z.infer<typeof schemaPaymentCard>;

@Controller('/payments')
export class PaymentController {
  constructor(private paymentRepository: PaymentRepository) {}

  @Get()
  async list() {
    return await this.paymentRepository.listCards();
  }

  @Get('/user/:user_id')
  async listByUser(@Param('user_id') userId: string) {
    return await this.paymentRepository.listCardsByUserId(userId);
  }

  @Post()
  @UsePipes(new ZodValidationPipe(schemaPaymentCard))
  async create(@Body() session: PaymentBodySchema) {
    return await this.paymentRepository.createCard(session);
  }

  @Get(':id')
  async getById(@Param('id') id: string) {
    return await this.paymentRepository.getCardById(id);
  }

  @Put(':id')
  @UsePipes(new ZodValidationPipe(schemaPaymentCard))
  async update(@Param('id') id: string, @Body() session: PaymentBodySchema) {
    return await this.paymentRepository.updateCard(id, session);
  }

  @Delete(':id')
  async delete(@Param('id') id: string) {
    return await this.paymentRepository.deleteCard(id);
  }
}
