import {
  Controller,
  Get,
  Post,
  Put,
  Delete,
  Body,
  Param,
  UsePipes,
} from '@nestjs/common';
import z from 'zod';
import { ZodValidationPipe } from '../pipes/zod-validation-pipe';
import { SocialMediaRepository } from '@/core/social-media/social-media-repository';

const schemaSocialMedia = z.object({
  userId: z.string(),
  url: z.string(),
  type: z.string(),
});

type SocialMediaBodySchema = z.infer<typeof schemaSocialMedia>;

@Controller('/social-medias')
export class SocialMediaController {
  constructor(private socialMediaRepository: SocialMediaRepository) {}

  @Get(':userId')
  async getAllByUser(@Param('userId') userId: string) {
    return await this.socialMediaRepository.getAllByUserId(userId);
  }

  @Post()
  async create(@Body() body: SocialMediaBodySchema) {
    return await this.socialMediaRepository.create(body);
  }

  @Put(':id')
  @UsePipes(new ZodValidationPipe(schemaSocialMedia))
  async update(
    @Param('id') id: string,
    @Body() socialMedia: SocialMediaBodySchema,
  ) {
    return await this.socialMediaRepository.update(id, socialMedia);
  }

  @Delete(':id')
  async delete(@Param('id') id: string) {
    await this.socialMediaRepository.delete(id);
  }

  @Get()
  async get() {
    return await this.socialMediaRepository.getAll();
  }
}
