import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { getFirstName } from 'src/app/helper/utils';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';

@Component({
  selector: 'app-navbar',
  templateUrl: './navbar.component.html',
  styleUrls: ['./navbar.component.scss']
})
export class NavbarComponent implements OnInit {

  user: any;
  showMenuMobile = false;

  routes = [{
    name: 'Minhas sessões',
    icon: 'comments',
    route: '/minhas-sessoes'
  }, {
    name: 'Mentores',
    icon: 'user-group',
    route: '/mentores'
  },
  {
    name: 'Mensagens',
    icon: 'comment',
    route: '/chat'
  },
  //todo Descontinuar esse item e colocar o link no avatar
  {
    name: 'Meu Perfil',
    icon: 'user',
    route: '/meu-perfil'
  }]

  mentorRoutes = [{
    name: 'Dashboard',
    icon: 'chart-line',
    route: '/dashboard'
  }]

  adminRoutes = [{
    name: 'Administradores',
    icon: 'user-group',
    route: '/administradores'
  }, {
    name: 'Conhecimentos',
    icon: 'brain',
    route: '/conhecimentos'
  }, {
    name: 'Relatórios',
    icon: 'file',
    route: '/relatorios'
  }, {
    name: 'Denúncias',
    icon: 'circle-exclamation',
    route: '/denuncias'
  }]

  constructor(
    private authenticationService: AuthenticationService,
    private router: Router
  ) { }

  ngOnInit() {
    this.authenticationService.user$.subscribe(user => {
      this.user = user;
    })

    if (this.user.isAdmin) {
      this.routes = [...this.routes, ...this.adminRoutes]
    }

    if (this.user.isMentor) {
      this.routes = [...this.mentorRoutes, ...this.routes]
    }
  }

  abreviate(name: any) {
    return getFirstName(name)
  }

  logout() {
    this.authenticationService.logout().subscribe(data => {
      this.router.navigate(['/login'])
    });
  }
}
