import { Component, OnInit } from '@angular/core';
import { ApexOptions} from "ng-apexcharts";
import { reportMentorsChartOptions, financialMetricsChartOptions, userGrowthChartOptions, userTypeMetricsChartOptions} from './chartOptions';
import { UserService } from 'src/app/services/user.service';
import * as Papa from 'papaparse';


@Component({
  selector: 'app-report',
  templateUrl: './admin-reports.component.html',
  styleUrls: ['./admin-reports.component.scss']
})
export class AdminReportsComponent implements OnInit {

  public reportMentorsChartOptions: Partial<ApexOptions> = {} as ApexOptions
  public financialChartOptions: Partial<ApexOptions> = {} as ApexOptions
  public userGrowthChartOptions: Partial<ApexOptions> = {} as ApexOptions
  public userTypeMetricsChartOptions: Partial<ApexOptions> = {} as ApexOptions
  public overviewReport = {}
  public reportDataLoaded: boolean = false;

  constructor(
    private userService: UserService
  ) {}

  ngOnInit() {
    this.userService
    .getAdminReportsData()
    .subscribe((data: any) => {
      this.reportDataLoaded = true;
      this.financialChartOptions = financialMetricsChartOptions(data.financialMetrics)
      this.reportMentorsChartOptions = reportMentorsChartOptions(data.reports)
      this.userGrowthChartOptions = userGrowthChartOptions(data.userGrowthByMonth)
      this.userTypeMetricsChartOptions = userTypeMetricsChartOptions(data.userTypeMetrics)
    })
  }


  downloadCsv() {
    this.userService
    .getOverviewMetrics()
    .subscribe(async (data: any) => {
      await this.convertJsonToCsv(data)
    })
  }

  private async convertJsonToCsv(jsonData: any) {
    // Convert back to CSV
    var csvData = Papa.unparse(jsonData);

    // Criar um blob de dados CSV
    const blob = new Blob([csvData], { type: 'text/csv' });

    // Criar um objeto URL do blob
    const url = window.URL.createObjectURL(blob);

    // Criar um link para o download do arquivo CSV
    const a = document.createElement('a');
    a.href = url;
    a.download = 'overview-report.csv';

    // Simular o clique no link para iniciar o download
    a.click();

    // Liberar o objeto URL
    window.URL.revokeObjectURL(url);
  }
}
