import { ApexOptions } from "ng-apexcharts";

type FinancialMetrics = {
  data: string,
  total_month: number,
}

type SessionRequestMetrics = {
  per_day: number,
  session_date: string,
  percentage_increase: number,
  number_sessions_last_30_days: string
  number_sessions_last_60_days: string
}

type UserMetrics = {
  per_day: number,
  session_date: string,
  percentage_increase: number,
  number_sessions_last_30_days: string
  number_sessions_last_60_days: string
}

type SessionMetrics = {
  per_day: number,
  session_date: string,
  percentage_increase: number,
  number_sessions_last_30_days: string
  number_sessions_last_60_days: string
}

type ReportMentors = {
  count: number,
  description: string
}

type userTypeMetrics = {
  isMentor: boolean,
  percentage: number,
  total: number
}


export const reportMentorsChartOptions = (report: ReportMentors[]): ApexOptions  => {
  const categories = report.map((d: ReportMentors) => d.description)
  const data = report.map((d: ReportMentors) => d.count)


  return  {
    series: [
      {
        name: "Denúncias",
        data
      }
    ],
    chart: {
      height: 350,
      type: "bar",
      events: {
        click: function(chart, w, e) {
          // console.log(chart, w, e)
        }
      }
    },
    colors: [
      "#008FFB",
      "#00E396",
      "#FF00FF",
      "#FEB019",
      "#FF4560",
      "#775DD0",
      "#546E7A",
      "#26a69a",
      "#D10CE8",
      "#00FFFF",
      "#FFA500"
    ],
    plotOptions: {
      bar: {
        columnWidth: "45%",
        distributed: true
      }
    },
    dataLabels: {
      enabled: false
    },
    legend: {
      show: false
    },
    grid: {
      show: false
    },
    xaxis: {
      categories,
      labels: {
        style: {
          colors: [
            "#008FFB",
            "#00E396",
            "#FF00FF",
            "#FEB019",
            "#FF4560",
            "#775DD0",
            "#546E7A",
            "#26a69a",
            "#D10CE8",
            "#00FFFF",
            "#FFA500"
          ],
          fontSize: "12px"
        }
      }
    },
    title: {
      text: `Denúncias por motivo`,
      offsetX: 30,
      style: {
        fontSize: '14px',
      }
    }
    // subtitle: {
    //   text: 'Denúncias por motivo',
    //   offsetX: 30,
    //   style: {
    //     // color,
    //     fontSize: '14px',
    //     fontWeight: 'bold',
    //   }
    // }
  };
}

export const usersChartOptions = (userMetrics: UserMetrics[]): ApexOptions => {

  const generalMetric = userMetrics[userMetrics.length - 1]
  const percentageIncrease = generalMetric.percentage_increase
  const color = percentageIncrease > 0 ? 'green' : (percentageIncrease < 0 ? 'red' : 'gray');
  const subtitle = percentageIncrease > 0 ? `⬆ ${percentageIncrease}%` : (percentageIncrease < 0 ? `⬇ ${percentageIncrease}%` : '0%')

  const data = userMetrics.map((d: UserMetrics) => {
    return {
      x: d.session_date,
      y: Number(d.per_day)
    }
  })

  return {
    chart: {
      id: 'usersChart',
      // group: 'sparklines',
      type: 'area',
      height: 160,
      sparkline: {
        enabled: true
      },
    },
    stroke: {
      curve: 'smooth',
      // colors: ['#F44336', '#E91E63', '#9C27B0']
    },
    fill: {
      type: "solid",
      opacity: 1,
      colors: ['#F44336', '#E91E63', '#9C27B0']
    },
    series: [{
      name: 'Aprendizes',
      data
    }],
    labels: userMetrics.map((d: SessionMetrics) => d.session_date),
    yaxis: {
      min: 0
    },
    xaxis: {
      // type: 'datetime',
    },
    colors: ['#F44336', '#E91E63', '#9C27B0'],
    title: {
      text: `Aprendizes: ${generalMetric.number_sessions_last_30_days}`,
      offsetX: 30,
      style: {
        fontSize: '24px',
      }
    },
    subtitle: {
      text: subtitle,
      offsetX: 30,
      style: {
        color,
        fontSize: '14px',
        fontWeight: 'bold',
      }
    }
  }
}

export const userGrowthChartOptions = (data: FinancialMetrics[]): ApexOptions => {
  const dataLabels = data.map((d: FinancialMetrics) => d.total_month)

  return  {
    series: [
      {
        name: "Crescimento de usuários",
        data: dataLabels
      }
    ],
    chart: {
      height: 350,
      type: "bar"
    },
    plotOptions: {
      bar: {
        dataLabels: {
          position: "top" // top, center, bottom
        }
      }
    },
    dataLabels: {
      enabled: true,
      formatter: function(val) {
        return val + "";
      },
      offsetY: -20,
      style: {
        fontSize: "12px",
        colors: ["#304758"]
      }
    },

    xaxis: {
      categories: [
        "Jan",
        "Feb",
        "Mar",
        "Apr",
        "May",
        "Jun",
        "Jul",
        "Aug",
        "Sep",
        "Oct",
        "Nov",
        "Dec"
      ],
      position: "top",
      labels: {
        offsetY: -18
      },
      axisBorder: {
        show: false
      },
      axisTicks: {
        show: false
      },
      crosshairs: {
        fill: {
          type: "gradient",
          gradient: {
            colorFrom: "#D8E3F0",
            colorTo: "#BED1E6",
            stops: [0, 100],
            opacityFrom: 0.4,
            opacityTo: 0.5
          }
        }
      },
      tooltip: {
        enabled: true,
        offsetY: -35
      }
    },
    fill: {
      type: "gradient",
      gradient: {
        shade: "light",
        type: "horizontal",
        shadeIntensity: 0.25,
        gradientToColors: undefined,
        inverseColors: true,
        opacityFrom: 1,
        opacityTo: 1,
        stops: [50, 0, 100, 100]
      }
    },
    yaxis: {
      axisBorder: {
        show: false
      },
      axisTicks: {
        show: false
      },
      labels: {
        show: false,
        formatter: function(val) {
          return val + "";
        }
      }
    },
    title: {
      text: "Crescimento de usuários",
      // floating: 0,
      offsetY: 320,
      align: "center",
      style: {
        color: "#444"
      }
    }
  };
}

export const financialMetricsChartOptions = (financialMetrics: FinancialMetrics[]): ApexOptions => {
  const actual_year = financialMetrics.map((d: FinancialMetrics) => d.total_month)
  const max = Math.max(...financialMetrics.map((d: FinancialMetrics) => d.total_month))
  const min = Math.min(...financialMetrics.map((d: FinancialMetrics) => d.total_month))

  return {
    series: [
      {
        name: "Faturamento",
        data: actual_year
      }
    ],
    chart: {
      height: 350,
      type: "line",
      dropShadow: {
        enabled: true,
        color: "#000",
        top: 18,
        left: 7,
        blur: 10,
        opacity: 0.2
      },
      toolbar: {
        show: true,
        offsetX: 0,
        offsetY: 0,
        tools: {
          download: true,
          selection: true,
          zoom: true,
          zoomin: true,
          zoomout: true,
          pan: true,
          customIcons: []
        },
        export: {
          csv: {
            filename: 'faturamento',
            columnDelimiter: ',',
            headerCategory: 'category',
            headerValue: 'value',
            dateFormatter(timestamp: any) {
              return new Date(timestamp).toDateString()
            }
          },
          svg: {
            filename: 'faturamento.svg',
          },
          png: {
            filename: `faturamento.png`,
          }
        },
        autoSelected: 'zoom'
      }
    },
    colors: ["#77B6EA", "#545454"],
    dataLabels: {
      enabled: true,
      formatter: function(val) {
        return `R$ ${Number(val).toFixed(2)}`;
      }
    },
    stroke: {
      curve: "smooth"
    },
    title: {
      text: "Faturamento",
      align: "left"
    },
    grid: {
      borderColor: "#e7e7e7",
      row: {
        colors: ["#f3f3f3", "transparent"], // takes an array which will be repeated on columns
        opacity: 0.5
      }
    },
    markers: {
      size: 1
    },
    xaxis: {
      categories: ["Jan", "Fev", "Mar", "Abr", "Maio", "Jun", "Jul", "Ago", "Set", "Out", "Nov", "Dez"],
      title: {
        text: "Mês"
      }
    },
    yaxis: {
      title: {
        text: "Real (R$)"
      },
      min,
      max,
      labels: {
        show: true,
        formatter: function(val) {
          return `R$ ${Number(val).toFixed(2)}`;
        }
      }
    },
    legend: {
      position: "top",
      horizontalAlign: "right",
      floating: true,
      offsetY: -10,
      offsetX: -5
    },

  }
};

export const userTypeMetricsChartOptions = (userTypeMetrics: userTypeMetrics[]): ApexOptions => {
  const [mentorees, mentor] = userTypeMetrics
  const [mentoreesPercentage, mentorPercentage] = [Number(mentorees.percentage).toFixed(2), Number(mentor.percentage).toFixed(2)]


  return  {
    series: [Number(mentoreesPercentage), Number(mentorPercentage)],
    chart: {
      width: 500,
      type: "pie"
    },
    labels: ["Mentores", "Mentoreados"],
    responsive: [
      {
        breakpoint: 400,
        options: {
          chart: {
            width: 200
          },
          legend: {
            position: "bottom"
          }
        }
      },
      {
        breakpoint: 300,
        options: {
          chart: {
            width: 200
          },
          legend: {
            position: "bottom"
          }
        }
      }
    ]
  };

}
