import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { createMask } from '@ngneat/input-mask';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import Swal from 'sweetalert2'
import { ErrorService } from 'src/app/services/error.service';
const swal = Swal as any;
@Component({
  selector: 'app-cadastro',
  templateUrl: './cadastro.component.html',
  styleUrls: ['./cadastro.component.scss']
})
export class CadastroComponent implements OnInit {

  cpfMask = createMask('999.999.999-99');

  cadastroForm: FormGroup;

  constructor(private authenticationService: AuthenticationService, private router: Router, private errorService: ErrorService, private fb: FormBuilder) {
    this.cadastroForm = this.fb.group({
      cpf: ['', Validators.required],
      nome: ['', Validators.required],
      email: ['', Validators.required],
      senha: ['', Validators.required],
      confirmarSenha: ['', Validators.required],
      isMentor: [false],
    });
  }

  ngOnInit() {
  }

  onSubmit() {
    if (!this.cadastroForm.valid) {
      swal.fire('', 'Favor preencher todos os campos', 'warning')
      return;
    }

    if (this.cadastroForm.value['senha'] !== this.cadastroForm.value['confirmarSenha']) {
      swal.fire('', 'Senhas não conferem')
      return;
    }

    let model = {
      name: this.cadastroForm.value['nome'],
      cpf: this.cadastroForm.value['cpf'].replaceAll('.', '').replace('-', ''),
      email: this.cadastroForm.value['email'],
      password: this.cadastroForm.value['senha'],
      avatar: '',
      abstract: '',
      isAdmin: false,
      isMentor: this.cadastroForm.value['isMentor']
    }

    this.authenticationService.createUser(model).subscribe(data => {
      this.authenticationService.updateUserSession(data);
      this.router.navigate(['/meu-perfil'])
      swal.fire('', 'Preencha o seu perfil', 'warning')
    }, error => {
      this.errorService.showErrorMessage(error)
    })

  }
}