import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { TopicsService } from 'src/app/services/topics.service';
import Swal from 'sweetalert2'
import { ErrorService } from 'src/app/services/error.service';
const swal = Swal as any;

@Component({
  selector: 'app-conhecimentos',
  templateUrl: './conhecimentos.component.html',
  styleUrls: ['./conhecimentos.component.scss']
})
export class ConhecimentosComponent implements OnInit {

  constructor(private topicsService: TopicsService, private router: Router, private fb: FormBuilder, private errorService: ErrorService,
  ) {
    this.form = this.fb.group({
      id: [''],
      nome: ['', Validators.required],
    });
  }

  listTopics: any[] = [];
  form: FormGroup;

  listTopicsFiltered: any = []

  ngOnInit() {
    this.getTopics()
  }

  onSearch(e: any) {
    const text = e.target.value;
    this.listTopicsFiltered = this.listTopics.filter(topic => topic['name'].toString().toLowerCase().indexOf(text.toLowerCase()) !== -1);
  }

  getTopics() {
    this.resetForm();
    this.topicsService.getTopics().subscribe(data => {
      this.listTopicsFiltered = this.listTopics = data;
    }, error => {
      this.errorService.showErrorMessage(error)
    });
  }

  setEdit(topic: any) {
    this.form.patchValue({
      nome: topic.name,
      id: topic.id
    })
  }

  onSaveTopic() {
    if (!this.form.valid) {
      swal.fire('', 'Favor preencher o nome do conhecimento', 'error')
      return;
    }

    let model = {
      name: this.form.value['nome'],
      active: true,
    }

    if (this.form.value['id']) {
      this.editTopic(this.form.value['id'], model)
    } else {
      this.createTopic(model)
    }
  }

  createTopic(model: any) {
    this.topicsService.postTopic(model).subscribe(data => {
      swal.fire('', 'Conhecimento cadastrado com sucesso', 'success')
      this.getTopics();
    }, error => {
      this.errorService.showErrorMessage(error)
    });
  }


  editTopic(id: any, model: any) {
    this.topicsService.putTopic(id, model).subscribe(data => {
      swal.fire('', 'Conhecimento salvo com sucesso', 'success');
      this.getTopics();
    }, error => {
      this.errorService.showErrorMessage(error)
    });
  }

  deleteTopic(topic: any) {
    swal.fire({
      title: 'Deseja excluir o conhecimento?',
      showCancelButton: true,
      confirmButtonText: 'Confirmar exclusão',
      confirmButtonColor: '#dc2626',
      cancelButtonText: 'Cancelar',
      cancelButtonColor: '#374151',
      reverseButtons: true,
    }).then((result: any) => {
      if (result.isConfirmed) {
        this.topicsService.deleteTopic(topic.id).subscribe(data => {
          swal.fire('Excluído com sucesso', '', 'success')
          this.getTopics();
        }, error => {
          this.errorService.showErrorMessage(error)
        })
      }
    })
  }
  
  resetForm() {
    this.listTopicsFiltered = this.listTopics;
    this.form.reset()
  }
}