import { Component, OnInit } from '@angular/core';
import { ApexOptions} from "ng-apexcharts";
import { financialChartOptions, sessionChartOptions, sessionRequestsChartOptions, usersChartOptions } from './chartOptions';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { UserService } from 'src/app/services/user.service';

@Component({
  selector: 'app-dashboard',
  templateUrl: './dashboard.component.html',
  styleUrls: ['./dashboard.component.scss']
})
export class DashboardComponent implements OnInit {

  public sessionChartOptions: Partial<ApexOptions> = {} as ApexOptions
  public usersChartOptions: Partial<ApexOptions> = {} as ApexOptions
  public sessionRequestsChartOptions: Partial<ApexOptions> = {} as ApexOptions
  public financialChartOptions: Partial<ApexOptions> = {} as ApexOptions

  dashboardLoaded = false;

  constructor(
    private auth: AuthenticationService,
    private userService: UserService
  ) {
  }

  ngOnInit() {
    this.userService
    .getDashboardData(this.auth.getUserSession()['id'])
    .subscribe((data: any) => {
      this.sessionChartOptions = sessionChartOptions(data['sessionsMetrics'])
      this.usersChartOptions = usersChartOptions(data['usersMetrics'])
      this.sessionRequestsChartOptions = sessionRequestsChartOptions(data['sessionRequestsMetrics'])
      this.financialChartOptions = financialChartOptions(data['financialMetrics'])
      this.dashboardLoaded = true;
    })
  }
}
