import { Component, OnInit, ViewChild } from '@angular/core';
import { getTimeAgo } from 'src/app/helper/utils';
import { ErrorService } from 'src/app/services/error.service';
import { ReportService } from 'src/app/services/report.service';
import { UserService } from 'src/app/services/user.service';
import Swal from 'sweetalert2'
const swal = Swal as any;

type Report = {
  id: string;
  description: string;
  reported_user_name: string;
  reported_user_id: string;
  reporting_user_name: string;
  reporting_user_id: string;
  reason: string;
  createdAt: string;
  collapsed: boolean;
  is_banned: boolean;
  start_ban: string;
  end_ban: string;
}

@Component({
  selector: 'app-denuncias',
  templateUrl: './denuncias.component.html',
  styleUrls: ['./denuncias.component.scss']
})
export class DenunciasComponent implements OnInit {

  isModalBanOpen = false;
  motivoBan: string = '';
  idUserBan: string = '';
  startDateBan: string = '';
  endDateBan: string = '';
  isPermaban: boolean = false;


  public reports: Report[] = [];

  constructor(
    private reportService: ReportService,
    private userService: UserService,
    private errorService: ErrorService
  ) {
    
  }

  ngOnInit() {
    this.buscarDenuncias()
   }

  buscarDenuncias() {
    this.reportService.getReports().subscribe((data: Report[]) => {
      this.reports = data;
    })
  }

  getTimeAgo(date: string) {
    return getTimeAgo(date)
  }

  onSearch(e: any) {
    // const text = e.target.value;
    // this.mentorsFiltered = this.mentors.filter(mentor => mentor?.name?.toString().toLowerCase().indexOf(text.toLowerCase()) !== -1);
  }

  openModalBan(idUserBan: string) {
    this.isModalBanOpen = true;
    this.idUserBan = idUserBan;
  }

  banUser() {
    if (!this.motivoBan) {
      swal.fire('', 'Favor preencher o motivo do banimento', 'warning')
      return;
    }

    if (!this.isPermaban && (!this.startDateBan || !this.endDateBan)) {
      swal.fire('', 'Favor preencher o período do banimento', 'warning')
      return;
    }

    let startDateToSend = ''
    let endDateToSend = ''

    if (this.isPermaban) {
      const now = new Date();
      startDateToSend = now.toISOString();
      endDateToSend = new Date(now.setFullYear(now.getFullYear() + 1000)).toISOString()
    } else {
      startDateToSend = new Date(this.startDateBan).toISOString();
      endDateToSend = new Date(this.endDateBan).toISOString();

      if (this.startDateBan >= this.endDateBan) {
        startDateToSend = ''
        endDateToSend = ''
        swal.fire('', 'Data de fim deve ser posterior a data de início', 'warning')
        return;
      }
    }

    let model = {
      reason: this.motivoBan,
      permanently: this.isPermaban,
      startDate: startDateToSend,
      endDate: endDateToSend,
    }

    this.userService.banUser(this.idUserBan, model).subscribe(data => {
      swal.fire('', 'Usuário banido com sucesso', 'success')
      this.buscarDenuncias()
      this.closeReportModal();
    }, error => {
      this.errorService.showErrorMessage(error)
    })
  }

  closeReportModal() { this.isModalBanOpen = false; }

}
