import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import Swal from 'sweetalert2'
const swal = Swal as any;
@Component({
  selector: 'app-esqueci-senha',
  templateUrl: './esqueci-senha.component.html',
  styleUrls: ['./esqueci-senha.component.scss']
})
export class EsqueciSenhaComponent implements OnInit {

  step = 1;
  tokenValido = false;
  esqueciSenhaForm: FormGroup;
  tokenForm: FormGroup;
  novaSenhaForm: FormGroup;
  userId = '';

  constructor(private authenticationService: AuthenticationService, private router: Router, private fb: FormBuilder) {
    this.esqueciSenhaForm = this.fb.group({
      email: ['', Validators.required],
    });

    this.tokenForm = this.fb.group({
      token: ['', Validators.required],
    });

    this.novaSenhaForm = this.fb.group({
      senha: ['', Validators.required],
      confirmarSenha: ['', Validators.required],
    });
  }

  ngOnInit() {
  }

  voltar() {
    this.router.navigate(['/mentores'])
  }

  onEsqueciSenha() {
    if (!this.esqueciSenhaForm.valid) {
      swal.fire('', 'Favor preencher o email', 'warning');
      return;
    }

    let model = {
      email: this.esqueciSenhaForm.value['email'],
    }

    this.authenticationService.forgotPassword(model).subscribe((data: any) => {
      console.log('token', data)
      this.step = 2;
    })

  }

  onValidarToken() {
    if (!this.tokenForm.valid) {
      swal.fire('', 'Favor preencher o token', 'warning');
      return;
    }
    
    let model = {
      token: this.tokenForm.value['token'],
      email: this.esqueciSenhaForm.value['email']
    }

    this.authenticationService.validateToken(model).subscribe((data: any) => {
      this.userId = data['userId'];
      this.tokenValido = true;
    })
  }

  onAtualizarSenha() {
    if (!this.novaSenhaForm.valid) {
      swal.fire('', 'Favor preencher a senha', 'warning');
      return;
    }

    if (this.novaSenhaForm.value['senha'] !== this.novaSenhaForm.value['confirmarSenha']) {
      swal.fire('', 'Senhas não conferem', 'warning');
      return;
    }

    let model = {
      newPassword: this.novaSenhaForm.value['senha'],
      userId: this.userId
    }

    this.authenticationService.refinePassword(model).subscribe((data: any) => {
      swal.fire('', 'Senha alterada com sucesso!', 'success').then((confirm: any) => {
        this.router.navigate(['/login'])
      })
    })
  }
}