import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { abreviateName, getFirstName } from 'src/app/helper/utils';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { UserService } from 'src/app/services/user.service';
import { User } from 'src/app/types';

type ScheduledSession = {
  id: string;
  name: string;
  startDate: string;
  endDate: string;
  session_time: string;
  rest_time: string;
};

type MentorOrStudent = {
  id: string;
  name: string;
  total_sessions: string;
};

type Payload = {
  totalSessions: number;
  nextScheduledSessions: ScheduledSession[];
  users: MentorOrStudent[];
};

@Component({
  selector: 'app-home',
  templateUrl: './home.component.html',
  styleUrls: ['./home.component.scss']
})
export class HomeComponent implements OnInit {

  public homePageData: Payload = {} as Payload
  public user: Partial<User> = {} as Partial<User>

  constructor(
    private auth: AuthenticationService,
    private userService: UserService,
    private router: Router
  ) {

    this.user = this.auth.getUserSession()

    userService
    .getMentorHomePage(this.user.id || '')
    .subscribe((data: Payload) => {
      this.homePageData = data
    })
  }

  ngOnInit() {}

  abreviate(name: any) {
    return abreviateName(name)
  }

  getFirstName(name: any) {
    return getFirstName(name)
  }

  getTimeRemaining(date: string) {
    const now = new Date().getTime();
    const targetDate = new Date(date).getTime();
    const timeRemaining = targetDate - now;

    if (timeRemaining <= 0) {
      return 'Começando agora';
    }

    const seconds = Math.floor(timeRemaining / 1000);
    const minutes = Math.floor(seconds / 60);
    const hours = Math.floor(minutes / 60);
    const days = Math.floor(hours / 24);

    if (days > 0) {
      return `${days} dias`;
    }

    if (hours > 0) {
      return `${hours} horas`;
    }

    if (minutes > 0) {
      return `${minutes} minutos`;
    }

    return `${seconds} segundos`;
  }

  // voltar(){
  //   this.router.navigate(['/mentores'])
  // }

  // logout() {
  //   this.authenticationService.logout();
  //   this.router.navigate(['/login'])
  // }
}
