import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { createMask } from '@ngneat/input-mask';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import Swal from 'sweetalert2'
const swal = Swal as any;
@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.scss']
})
export class LoginComponent implements OnInit {

  cpfMask = createMask('999.999.999-99');

  loginForm: FormGroup;

  constructor(private authenticationService: AuthenticationService, private router: Router, private fb: FormBuilder) {
    this.loginForm = this.fb.group({
      cpf: ['', Validators.required],
      senha: ['', Validators.required],
    });
  }

  ngOnInit() {
    if (this.authenticationService.getUserSession()) {
      this.router.navigate(['/mentores'])
    }
  }

  voltar() {
    this.router.navigate(['/mentores'])
  }

  onSubmit() {
    if (!this.loginForm.valid) {
      swal.fire('', 'Favor preencher todos os campos', 'warning')
      return;
    }

    let model = {
      cpf: this.loginForm.value['cpf'].replaceAll('.', '').replace('-', ''),
      password: this.loginForm.value['senha'],
    }

    this.authenticationService.login(model).subscribe(({ user }: any) => {

      this.authenticationService.updateUserSession(user);
      this.router.navigate(['mentores'])
    }, err => {
      swal.fire('', 'Usuário ou senha incorretos', 'error')
    });
  }

  logout() {
    this.authenticationService.logout();
    this.router.navigate(['/login'])
  }
}
