import { Component, OnInit } from '@angular/core';
import { UserService } from 'src/app/services/user.service';
import { TopicsService } from 'src/app/services/topics.service';
import { Router } from '@angular/router';
import { Topic, User } from 'src/app/types';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';

@Component({
  selector: 'app-mentores',
  templateUrl: './mentores.component.html',
  styleUrls: ['./mentores.component.scss']
})
export class MentoresComponent implements OnInit {

  public mentors: Partial<User>[] = [];
  public mentorsFiltered: Partial<User>[] = [];
  public topics: Topic[] = [];
  user: any;

  selectedItems: any = [];
  dropdownSettings: any;

  constructor(
    private userService: UserService,
    private topicsService: TopicsService,
    private authenticationService: AuthenticationService,
    private router: Router) { }

  ngOnInit() {
    this.authenticationService.user$.subscribe(user => {
      this.user = user;
    })

    this.userService.getMentors().subscribe(data => {
      // remove self
      data = data.filter((item: any) => item.id != this.user.id)
      this.mentorsFiltered = this.mentors = data
    });

    this.getTopics()
  }

  getTopics() {
    this.topicsService.getTopics().subscribe(data => {
      this.topics = data;
    })
  }

  onItemClickFired(event: any) {
    this.mentorsFiltered = this.findObjectsWithTopics(this.mentors, this.selectedItems)
  }

  findObjectsWithTopics(inputList: any, topicList: any) {
    if (topicList.length < 1) {
      return inputList;
    }

    const result = inputList.filter((obj: any) =>
      obj.userTopics.some((userTopic: any) =>
        topicList.some((topic: any) => topic.id === userTopic.topic.id)
      )
    );

    return result;
  }

  onSearch(e: any) {
    const text = e.target.value;
    this.mentorsFiltered = this.mentors.filter(mentor => mentor?.name?.toString().toLowerCase().indexOf(text.toLowerCase()) !== -1);
  }

  seeProfile(id: string) {
    this.router.navigate(['/perfil', id])
  }

  solicitarSessao(mentor: any) {
    this.router.navigate(['/solicitar-sessao'])
    this.userService.mentorRequestSession = mentor;
  }
}
