import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { ErrorService } from 'src/app/services/error.service';
import Swal from 'sweetalert2'
const swal = Swal as any;

@Component({
  selector: 'app-configuracoes',
  templateUrl: './configuracoes.component.html',
  styleUrls: ['./configuracoes.component.scss']
})
export class ConfiguracoesComponent implements OnInit {

  user: any;

  alterarSenhaForm: FormGroup;

  constructor(
    public authenticationService: AuthenticationService,
    private router: Router,
    private authService: AuthenticationService,
    private errorService: ErrorService,
    private fb: FormBuilder,
  ) {
    this.alterarSenhaForm = this.fb.group({
      // atual: ['', Validators.required],
      nova: ['', Validators.required],
      novaRepetir: ['', Validators.required],
    });
  }

  ngOnInit() {
    this.authenticationService.user$.subscribe(user => {
      this.user = user;
    })
  }

  alterarSenha() {
    if (!this.alterarSenhaForm.valid) {
      swal.fire('', 'Por favor preencha todos os campos', 'warning')
      return;
    }
    if (this.alterarSenhaForm.value['nova'] !== this.alterarSenhaForm.value['novaRepetir']) {
      swal.fire('', 'Senhas não coincidem', 'warning')
      return;
    }

    let model = {
      password: this.alterarSenhaForm.value['nova']
    }
    this.authService.changePassword(this.user.id, model).subscribe(data => {
      this.alterarSenhaForm.reset();
      swal.fire('', 'Senha alterada com sucesso', 'success')
    }, error => {
      this.errorService.showErrorMessage(error)
    })
  }
}
