import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { ErrorService } from 'src/app/services/error.service';
import { UserService } from 'src/app/services/user.service';
import Swal from 'sweetalert2'
const swal = Swal as any;

@Component({
  selector: 'app-dados-pessoais',
  templateUrl: './dados-pessoais.component.html',
  styleUrls: ['./dados-pessoais.component.scss']
})
export class DadosPessoaisComponent implements OnInit {

  user: any;

  dadosForm: FormGroup;

  constructor(
    public authenticationService: AuthenticationService,
    private userService: UserService,
    private router: Router,
    private errorService: ErrorService,
    private fb: FormBuilder,
  ) {
    this.dadosForm = this.fb.group({
      nome: [''],
      email: [''],
      descricao: [''],
    });
  }

  ngOnInit() {
    this.authenticationService.user$.subscribe(user => {
      this.user = user;
    })

    this.userService.getUserById(this.user['id']).subscribe(data => {
      this.dadosForm.patchValue({
        nome: data['name'],
        cpf: data['cpf'],
        email: data['email'],
        descricao: data['abstract'],
      })
    })
  }

  salvarDados() {
    let model = {
      name: this.dadosForm.value['nome'] || '',
      email: this.dadosForm.value['email'] || '',
      abstract: this.dadosForm.value['descricao'] || '',
      cpf: this.user['cpf'],
    };

    this.userService.putUser(this.user.id, model).subscribe(data => {
      swal.fire('', 'Dados salvos com sucesso', 'success')

    }, error => {
      this.errorService.showErrorMessage(error)
    })
  }
}
