import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { AvailabilityService } from 'src/app/services/availability.service';
import { ErrorService } from 'src/app/services/error.service';
import { UserService } from 'src/app/services/user.service';
import { Availability } from 'src/app/types';
import Swal from 'sweetalert2'
const swal = Swal as any;

@Component({
  selector: 'app-disponibilidade',
  templateUrl: './disponibilidade.component.html',
  styleUrls: ['./disponibilidade.component.scss']
})
export class DisponibilidadeComponent implements OnInit {

  user: any;

  availabilityForm: FormGroup;

  listaDisponibilidade: Availability[] = [];

  constructor(
    public authenticationService: AuthenticationService,
    private userService: UserService,
    private router: Router,
    private errorService: ErrorService,
    private fb: FormBuilder,
    private availabilityService: AvailabilityService,
  ) {
    this.availabilityForm = this.fb.group({
      diaSemana: ['Segunda', Validators.required],
      horaInicio: ['', Validators.required],
      minutoInicio: ['', Validators.required],
      horaFim: ['', Validators.required],
      minutoFim: ['', Validators.required],
    });
  }

  ngOnInit() {
    this.authenticationService.user$.subscribe(user => {
      this.user = user;
    })

    this.buscarDisponibilidade()
  }

  buscarDisponibilidade() {
    this.availabilityService.getAvailabilityByUser(this.user.id).subscribe(data => {
      this.listaDisponibilidade = data;
    }, error => {
      this.errorService.showErrorMessage(error)
    })
  }


  salvarDisponibilidade() {
    if (!this.availabilityForm.valid) {
      swal.fire('', 'Por favor preencha todos os campos', 'warning')
      return;
    }

    const horaInicio = this.availabilityForm.value['horaInicio'] + ':' + this.availabilityForm.value['minutoInicio']
    const horaFim = this.availabilityForm.value['horaFim'] + ':' + this.availabilityForm.value['minutoFim']

    if (horaInicio >= horaFim) {
      swal.fire('', 'Hora de início deve ser superior a hora final', 'warning')
      return;
    }

    let model = {
      startDate: horaInicio,
      endDate: horaFim,
      weekDay: this.availabilityForm.value['diaSemana'],
      userId: this.user.id,
    }

    this.availabilityService.postAvailability(model).subscribe(data => {
      swal.fire('', 'Salvo com sucesso!', 'success')
      this.availabilityForm.reset();
      this.buscarDisponibilidade()
    }, error => {
      this.errorService.showErrorMessage(error)
    })
  }

  deletarDisponibilidade(disponibilidade: Availability) {
    this.availabilityService
      .deleteAvailability(this.user.id, disponibilidade)
      .subscribe({
        next: _ => {
          swal.fire('', 'Deletado com sucesso!', 'success')
          this.buscarDisponibilidade()
        },
        error: error => {
          this.errorService.showErrorMessage("Erro ao deletar uma disponibilidade")
        }
      })
  }




}
