import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { ErrorService } from 'src/app/services/error.service';
import { UserService } from 'src/app/services/user.service';
import { ImageCroppedEvent, LoadedImage } from 'ngx-image-cropper';
import { DomSanitizer } from '@angular/platform-browser';
import { ModalService } from 'src/app/services/modal/modal.service';
import { User } from 'src/app/types';
import Swal from 'sweetalert2'
const swal = Swal as any;


@Component({
  selector: 'app-meu-perfil',
  templateUrl: './meu-perfil.component.html',
  styleUrls: ['./meu-perfil.component.scss']
})
export class MeuPerfilComponent implements OnInit {

  user: User = {} as User;
  tabId: number = 1;

  imageChangedEvent: any = '';
  croppedImage: any = '';

  constructor(
    public authenticationService: AuthenticationService,
    private userService: UserService,
    private router: Router,
    private errorService: ErrorService,
    private fb: FormBuilder,
    private sanitizer: DomSanitizer,
    private modalService: ModalService
  ) {

  }

  ngOnInit() {
    this.authenticationService.user$.subscribe(user => {
      this.user = user;
    })
  }

  changeTab(tabId: number) {
    this.tabId = tabId;
  }

  fileChangeEvent(event: any): void {
    this.imageChangedEvent = event;
  }

  imageCropped(event: ImageCroppedEvent) {
    this.croppedImage = event.base64;
  }

  imageLoaded(image: LoadedImage) { }

  cropperReady() {
    // cropper ready
  }
  loadImageFailed() {
    // show message
  }

  abrirModal() {
    this.modalService.abrirModal();
  }

  fecharModal() {
    this.modalService.fecharModal();
  }

  pad(n: number): string {
    return n < 10 ? '0' + n : n.toString();
  }

  salvarAvatar() {
    let model = {
      avatar: this.croppedImage
    };

    this.userService.putAvatar(this.user.id, model).subscribe({
      next: data => {
        this.authenticationService.updateUserSession({ ...this.user, avatar: data['url'] });
        swal.fire('', 'Foto de perfil alterada com sucesso', 'sucesso')
        this.fecharModal()
      },
      error: error => {
        this.errorService.showErrorMessage(error);
      }
    });
  }
}
