import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { createMask } from '@ngneat/input-mask';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { ErrorService } from 'src/app/services/error.service';
import { TopicsService } from 'src/app/services/topics.service';
import { UserService } from 'src/app/services/user.service';
import Swal from 'sweetalert2'
const swal = Swal as any;

@Component({
  selector: 'app-meus-conhecimentos',
  templateUrl: './meus-conhecimentos.component.html',
  styleUrls: ['./meus-conhecimentos.component.scss']
})
export class MeusConhecimentosComponent implements OnInit {

  user: any;

  conhecimentos: any;
  conhecimentosUsuario: any;

  conhecimentoForm: FormGroup;

  currencyInputMask = createMask({
    alias: 'numeric',
    groupSeparator: '',
    radixPoint: ',',
    digits: 2,
    digitsOptional: false,
    prefix: 'R$ ',
    placeholder: '0',
  });


  constructor(
    public authenticationService: AuthenticationService,
    private router: Router,
    private errorService: ErrorService,
    private fb: FormBuilder,
    private userService: UserService,
    private topicsService: TopicsService,
  ) {
    this.conhecimentoForm = this.fb.group({
      id: ['', Validators.required],
      valor: ['', Validators.required],
    });
  }

  ngOnInit() {
    this.authenticationService.user$.subscribe(user => {
      this.user = user;
    })

    this.buscarConhecimentos()
    this.buscarConhecimentosUsuario()
  }

  buscarConhecimentosUsuario() {
    this.conhecimentoForm.reset();
    this.topicsService.getTopicsByUserId(this.user.id).subscribe(data => {
      this.conhecimentosUsuario = data;
    })
  }

  buscarConhecimentos() {
    this.topicsService.getTopics().subscribe(data => {
      this.conhecimentos = data;
    })
  }

  salvarConhecimento() {
    if (!this.conhecimentoForm.valid) {
      swal.fire('', 'Por favor preencha todos os campos', 'warning')
      return;
    }

    const price = parseFloat(this.conhecimentoForm.value['valor'].replace('R$ ', '').replace(',', '.'));

    let model = {
      price,
      topicId: this.conhecimentoForm.value['id'],
      userId: this.user.id
    }

    this.topicsService.saveUserTopic(model).subscribe(data => {
      swal.fire('', 'Conhecimento cadastrado com sucesso', 'success')
      this.buscarConhecimentosUsuario()
    }, error => {
      this.errorService.showErrorMessage(error)
    })
  }

  excluirConhecimento(topicId: any) {
    swal.fire({
      title: 'Deseja excluir o conhecimento?',
      showCancelButton: true,
      confirmButtonText: 'Confirmar exclusão',
      confirmButtonColor: '#dc2626',
      cancelButtonText: 'Cancelar',
      cancelButtonColor: '#374151',
      reverseButtons: true,
    }).then((result: any) => {
      if (result.isConfirmed) {
        this.topicsService.deleteUserTopic(topicId).subscribe(data => {
          swal.fire('', 'Conhecimento excluído com sucesso', 'success')
          this.buscarConhecimentosUsuario()
        }, error => {
          this.errorService.showErrorMessage(error)
        })
      }
    })
  }
}
