import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { ErrorService } from 'src/app/services/error.service';
import { UserService } from 'src/app/services/user.service';
import Swal from 'sweetalert2'
const swal = Swal as any;

@Component({
  selector: 'app-redes-sociais',
  templateUrl: './redes-sociais.component.html',
  styleUrls: ['./redes-sociais.component.scss']
})
export class RedesSociaisComponent implements OnInit {

  user: any;

  socialMediaList: any;

  redeSocialForm: FormGroup;

  constructor(
    public authenticationService: AuthenticationService,
    private router: Router,
    private userService: UserService,
    private errorService: ErrorService,
    private fb: FormBuilder,
  ) {
    this.redeSocialForm = this.fb.group({
      id: [''],
      tipo: ['', Validators.required],
      url: ['', Validators.required],
    });

  }

  ngOnInit() {
    this.authenticationService.user$.subscribe(user => {
      this.user = user;
    })

    this.buscarRedesSociais()
  }

  setEdit(redeSocial: any) {
    this.redeSocialForm.patchValue({
      id: redeSocial.id,
      tipo: redeSocial.type,
      url: redeSocial.url,
    })
  }

  buscarRedesSociais() {
    this.redeSocialForm.reset();
    this.userService.getUserSocialMedia(this.user.id).subscribe(data => {
      this.socialMediaList = data;
    }, error => {
      this.errorService.showErrorMessage(error)
    })
  }

  salvarRedeSocial() {
    if (!this.redeSocialForm.valid) {
      swal.fire('', 'Por favor preencha todos os campos', 'warning')
      return;
    }

    let model = {
      type: this.redeSocialForm.value['tipo'],
      url: this.redeSocialForm.value['url'],
      userId: this.user.id
    }

    if (this.redeSocialForm.value['id']) {
      this.userService.putUserSocialMedia(this.redeSocialForm.value['id'], model).subscribe(data => {
        swal.fire('', 'Rede social salva com sucesso', 'success')
        this.buscarRedesSociais()
      }, error => {
        this.errorService.showErrorMessage(error)
      })
    } else {
      this.userService.postUserSocialMedia(model).subscribe(data => {
        swal.fire('', 'Rede social cadastrada com sucesso', 'success')
        this.buscarRedesSociais()
      }, error => {
        this.errorService.showErrorMessage(error)
      })
    }
  }

  deletarRedeSocial(socialMediaId: any) {
    this.userService.deleteUserSocialMedia(socialMediaId).subscribe(data => {
      swal.fire('', 'Rede social excluída com sucesso', 'success')
      this.buscarRedesSociais()
    }, error => {
      this.errorService.showErrorMessage(error)
    })
  }

}
