import { Component, OnInit } from '@angular/core';
import { getTimeAgo } from 'src/app/helper/utils';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { ErrorService } from 'src/app/services/error.service';
import { ModalService } from 'src/app/services/modal/modal.service';
import { UserService } from 'src/app/services/user.service';
import { Session, SessionPayload } from 'src/app/types';
import { User } from 'stream-chat';
import Swal from 'sweetalert2'
const swal = Swal as any;
@Component({
  selector: 'app-minhas-sessoes',
  templateUrl: './minhas-sessoes.component.html',
  styleUrls: ['./minhas-sessoes.component.scss']
})
export class MinhasSessoesComponent implements OnInit {

  user: User = {} as User;
  sessions: Partial<SessionPayload>[] = [];

  isModelAvaliarOpen = false;

  isModelCancelarOpen = false;
  idSessionCancel: string = ''
  motivoCancel: string = '';

  isModelDeclineOpen = false;
  motivoDecline: string = '';
  idSessionDecline: string = ''

  idSessionAccept: string = ''

  reviewMentorName: any;
  reviewMentorId: any;

  descricaoAvaliacao: any = '';
  notaAvaliacao = 5;

  constructor(
    private userService: UserService,
    private authenticationService: AuthenticationService,
    private errorService: ErrorService
  ) { }

  ngOnInit() {
    this.authenticationService.user$.subscribe(user => {
      this.user = user;
    })


    this.getSessions();
  }

  getSessions() {
    this.userService
      .getSessionsByUserId(this.user.id)
      .subscribe((sessions) => {
        this.sessions = sessions;
      })
  }

  acceptSession(id: string = '') {
    this.userService
      .acceptSession(id)
      .subscribe((response) => {
        swal.fire('', 'Sessão confirmada com sucesso!', 'success')

        this.getSessions();
      }, error => {
        this.errorService.showErrorMessage(error)
      })
  }



  onDeclineClick(id: string = '') {
    this.idSessionDecline = id
    this.isModelDeclineOpen = true;
  }

  closeDeclineModal() { this.isModelDeclineOpen = false; }


  declineSession() {
    this.userService
      .declineSession(this.idSessionDecline)
      .subscribe((response) => {
        this.getSessions();
      }, error => {
        this.errorService.showErrorMessage(error)
      })
  }

  onCancelClick(id: string = '') {
    this.idSessionCancel = id
    this.isModelCancelarOpen = true;
  }

  closeCancelModal() { this.isModelCancelarOpen = false; }

  cancelSession() {
    if (!this.motivoCancel) {
      swal.fire('', 'Preencha o motivo do cancelamento', 'warning')
      return;
    }

    this.userService
      .cancelSession(this.idSessionCancel, {cancelledReason: this.motivoCancel})
      .subscribe((response) => {
        this.isModelCancelarOpen = false;
        swal.fire('', 'Cancelamento realizado com sucesso', 'success')

        this.getSessions();
      }, error => {
        this.errorService.showErrorMessage(error)
      })
  }

  saveReviewModal() {
    if (!this.descricaoAvaliacao) {
      swal.fire('', 'Por favor descreva sobre a avaliação', 'warning')
      return;
    }
    let model = {
      mentorId: this.reviewMentorId,
      grade: this.notaAvaliacao,
      evaluation: this.descricaoAvaliacao,
    }
    this.userService.reviewMentor(this.user.id, model).subscribe(data => {
      swal.fire('', 'Avaliação realizada com sucesso', 'success')
      this.closeReviewModal();
    }, error => {
      this.errorService.showErrorMessage(error)
    })
  }
  
  openReviewModal(session: Partial<SessionPayload>) {
    this.reviewMentorName = session?.name;
    this.reviewMentorId = session?.studentOrMentorId;
    this.isModelAvaliarOpen = true;
  }

  closeReviewModal() { this.isModelAvaliarOpen = false; }


  getTimeAgo(date: string) {
   return getTimeAgo(date)
  }
}
