import { NgModule } from '@angular/core';
import { Routes, RouterModule } from '@angular/router';
import { LayoutComponent } from './_layout/layout.component';

const routes: Routes = [
  {
    path: '',
    component: LayoutComponent,
    children: [
      {
        path: 'mentores',
        loadChildren: () =>
          import('./mentores/mentores.module').then((m) => m.MentoresModule),
      },
      {
        path: 'minhas-sessoes',
        loadChildren: () =>
          import('./minhas-sessoes/minhas-sessoes.module').then((m) => m.MinhasSessoesModule),
      },
      {
        path: 'solicitar-sessao',
        loadChildren: () =>
          import('./solicitar-sessao/solicitar-sessao.module').then((m) => m.SolicitarSessaoModule),
      },
      {
        path: 'perfil/:id',
        loadChildren: () =>
          import('./perfil/perfil.module').then((m) => m.PerfilModule),
      },
      {
        path: 'pagamento',
        loadChildren: () =>
          import('./pagamento/pagamento.module').then((m) => m.PagamentoModule),
      },
      {
        path: 'editar-usuario',
        loadChildren: () =>
          import('./editar-usuario/editar-usuario.module').then((m) => m.EditarUsuarioModule),
      },
      {
        path: 'administradores',
        loadChildren: () =>
          import('./administradores/administradores.module').then((m) => m.AdministradoresModule),
      },
      {
        path: 'conhecimentos',
        loadChildren: () =>
          import('./conhecimentos/conhecimentos.module').then((m) => m.ConhecimentosModule),
      },
      {
        path: 'meu-perfil',
        loadChildren: () =>
          import('./meu-perfil/meu-perfil.module').then((m) => m.MeuPerfilModule),
      },
      {
        path: 'chat',
        loadChildren: () =>
          import('./chat/chat.module').then((m) => m.ChatModule),
      },
      {
        path: 'home',
        loadChildren: () =>
          import('./home/home.module').then((m) => m.HomeModule),
      },
      {
        path: 'dashboard',
        loadChildren: () =>
          import('./dashboard/dashboard.module').then((m) => m.DashboardModule),
      },
      {
        path: 'denuncias',
        loadChildren: () =>
          import('./denuncias/denuncias.module').then((m) => m.DenunciasModule),
      },
      {
        path: 'relatorios',
        loadChildren: () =>
          import('./admin-reports/admin-reports.module').then((m) => m.AdminReportsModule),
      }
    ],
  },
  {
    path: 'sobre',
    loadChildren: () =>
      import('./landing-page/landing-page.module').then((m) => m.LandingPageModule),
  },
  {
    path: 'cadastro',
    loadChildren: () =>
      import('./cadastro/cadastro.module').then((m) => m.CadastroModule),
  },
  {
    path: 'login',
    loadChildren: () =>
      import('./login/login.module').then((m) => m.LoginModule),
  },
  {
    path: 'esqueci-senha',
    loadChildren: () =>
      import('./esqueci-senha/esqueci-senha.module').then((m) => m.EsqueciSenhaModule),
  },

  // erro
  {
    path: '**',
    redirectTo: 'erro',
  },
  {
    path: 'erro',
    loadChildren: () =>
      import('./erro/erro.module').then((m) => m.ErroModule),
  },
];


@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})


export class PagesRoutingModule { }
