import { Component, OnInit } from '@angular/core';
import { UserService } from 'src/app/services/user.service';
import { ActivatedRoute, Router } from '@angular/router';
import { ChatService } from 'src/app/services/chat/chat.service';
import { User } from 'src/app/types';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import { ReportService } from 'src/app/services/report.service';
import { ErrorService } from 'src/app/services/error.service';
import Swal from 'sweetalert2'
const swal = Swal as any;
@Component({
  selector: 'app-perfil',
  templateUrl: './perfil.component.html',
  styleUrls: ['./perfil.component.scss']
})
export class PerfilComponent implements OnInit {

  currentUser: any;
  public user: User = {} as User;
  public mentorId = '';

  reportReasonList: any;

  isModalReportOpen: boolean = false;
  motivoReport: any = '';
  reportDescription: any;

  constructor(
    private mentorService: UserService,
    private router: Router,
    private chatService: ChatService,
    private route: ActivatedRoute,
    private userService: UserService,
    private authenticationService: AuthenticationService,
    private reportService: ReportService,
    private errorService: ErrorService
  ) { }

  ngOnInit() {
    this.authenticationService.user$.subscribe(user => {
      this.currentUser = user;
    })

    this.reportService.getReportsReasons().subscribe(data => {
      this.reportReasonList = data
    })

    this.route.params.subscribe((params) => {
      const id = params['id'] || '';
  
      if (!id) {
        this.router.navigate(['/erro'])
        return;
      }

      this.mentorService
        .getUserByIdToMentorView(id)
        .subscribe(data => {
          this.user = data;
        })
    });
  }

  async createChat({ name, id }: any) {
    await this.chatService.newChannel(name, id);
    this.router.navigate(['/chat'])
  }

  solicitarSessao(mentor: any) {
    this.router.navigate(['/solicitar-sessao'])
    this.userService.mentorRequestSession = mentor;
  }

  openReportModal() {
    this.isModalReportOpen = true;
  }

  reportUser() {
    const idReportedUser = this.user.id;

    if (!this.motivoReport || !this.reportDescription) {
      swal.fire('', 'Por favor preencha os campos de denúncia', 'warning')
      return;
    }
    let model = {
      reportReasonId: this.motivoReport,
      description: this.reportDescription,
      reportedUserId: idReportedUser
    }
    this.reportService.postReport(this.currentUser.id, model).subscribe(data => {
      swal.fire('', 'Sua denúncia foi gravada, logo será verificada pelos administradores', 'success')
      this.closeReportModal();
    }, error => {
      this.errorService.showErrorMessage(error)
    })
  }

  closeReportModal() { this.isModalReportOpen = false; }

}
