import { Component, OnInit } from '@angular/core';
import { UserService } from 'src/app/services/user.service';
import { TopicsService } from 'src/app/services/topics.service';
import { Router } from '@angular/router';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { AvailabilityService } from 'src/app/services/availability.service';
import { MaskedDate } from 'src/app/helper/mask.helper';
import { SessionService } from 'src/app/services/session.service';
import { AuthenticationService } from 'src/app/services/auth/authentication.service';
import Swal from 'sweetalert2'
import { createMask } from '@ngneat/input-mask';
const swal = Swal as any;
@Component({
  selector: 'app-solicitar-sessao',
  templateUrl: './solicitar-sessao.component.html',
  styleUrls: ['./solicitar-sessao.component.scss']
})
export class SolicitarSessaoComponent implements OnInit {

  user: any;

  solicitarSessaoForm: FormGroup;
  userTopics: any = [];
  listaDisponibilidade: any = [];
  mentor: any;
  dateMask = MaskedDate;
  date: any;

  combinar: any;
  qtdHorasCombinar: any;
  availabilityId: any;
  horasMask = createMask('9');

  todayDate: Date = new Date();

  diasDaSemana = ['Domingo', 'Segunda', 'Terça', 'Quarta', 'Quinta', 'Sexta', 'Sábado'];
  diasDaSemanaDisponiveis: any = [];

  dataInicioToSend: any;
  dataFimToSend: any;


  constructor(
    public authenticationService: AuthenticationService,
    private userService: UserService,
    private router: Router,
    private fb: FormBuilder,
    private topicsService: TopicsService,
    private availabilityService: AvailabilityService,
    private sessionService: SessionService,
  ) {
    this.solicitarSessaoForm = this.fb.group({
      descricao: ['', Validators.required],
      topic: ['', Validators.required],
    });
  }

  ngOnInit() {
    this.authenticationService.user$.subscribe(user => {
      this.user = user;
    })

    if (!this.userService.mentorRequestSession) {
      this.router.navigate(['/mentores'])
      return;
    }

    this.mentor = this.userService.mentorRequestSession

    this.getTopics();
    this.buscarDisponibilidade();
  }

  public myFilter = (d: any): boolean => {
    const day = d.getDay();

    return this.diasDaSemanaDisponiveis.indexOf(this.diasDaSemana[day]) > -1;
  }

  getTopics() {
    const mentorId = this.mentor['id'];

    this.topicsService.getTopicsByUserId(mentorId).subscribe(data => {
      this.userTopics = data;
    })
  }


  calcularDiferencaEmDecimal(dataInicialStr: any, dataFinalStr: any) {
    const dataInicial = new Date(dataInicialStr);
    const dataFinal = new Date(dataFinalStr);

    const diffEmMilissegundos = Math.abs(dataFinal.getTime() - dataInicial.getTime());
    const diffEmHoras = diffEmMilissegundos / (1000 * 60 * 60);

    const diffEmDecimal = parseFloat(diffEmHoras.toFixed(2));

    return diffEmDecimal;
  }

  solicitarSessao() {
    if (!this.solicitarSessaoForm.value['descricao']) {
      swal.fire('', 'Por favor preencha a descrição', 'warning')
      return;
    }

    if (!this.solicitarSessaoForm.value['topic']) {
      swal.fire('', 'Por favor selecione o tópico', 'warning')
      return;
    }

    if (!this.date) {
      swal.fire('', 'Por favor escolha a data', 'warning')
      return;
    }

    if (this.combinar) {
      this.dataInicioToSend = this.date;
      this.dataInicioToSend.setHours(0)
      this.dataInicioToSend.setMinutes(0)
      this.dataInicioToSend = this.dataInicioToSend.toISOString()

      this.dataFimToSend = this.date;
      this.dataFimToSend.setHours(23)
      this.dataFimToSend.setMinutes(59)
      this.dataFimToSend = this.dataFimToSend.toISOString()

      if (!this.qtdHorasCombinar || this.qtdHorasCombinar < 1) {
        swal.fire('', 'Por favor preencha a quantidade de horas pretendidas', 'warning')
        return;
      }
    }

    if (!this.dataInicioToSend || !this.dataFimToSend) {
      swal.fire('', 'Por favor escolha o horário', 'warning')
      return;
    }

    const topicId = this.solicitarSessaoForm.value['topic'];
    const selectedTopic = this.userTopics.find((item: any) => item.id == topicId)
    const topicPrice = selectedTopic['price']

    const sessionDuration = this.combinar ? this.qtdHorasCombinar : this.calcularDiferencaEmDecimal(this.dataInicioToSend, this.dataFimToSend)

    const totalValue = sessionDuration * topicPrice;


    let model = {
      startDate: this.dataInicioToSend,
      endDate: this.dataFimToSend,
      studentId: this.user.id,
      mentorId: this.mentor['id'],
      userTopicId: this.solicitarSessaoForm.value['topic'],
      description: this.solicitarSessaoForm.value['descricao'],
      toCombine: this.combinar || false,
      combinedHours: parseInt(this.qtdHorasCombinar) || undefined,
      totalValue: totalValue,
      availabilityId: this.availabilityId
    }


    this.sessionService.sessionToPay = model;
    this.sessionService.sessionToPayDetails = {
      mentor: this.mentor,
      topic: selectedTopic,
      sessionDuration,
    };

    this.router.navigate(['/pagamento'])
  }

  buscarDisponibilidade() {
    this.availabilityService.getAvailabilityWeekDaysByUser(this.mentor.id).subscribe(data => {
      this.diasDaSemanaDisponiveis = data.map((item: any) => item.weekDay);

      if (this.diasDaSemanaDisponiveis.length < 1) {
        this.diasDaSemanaDisponiveis = this.diasDaSemana;
      }
    })
  }

  onUpdateDate() {
    this.availabilityService.searchUserAvailabilityByDate(this.mentor.id, this.date.toISOString()).subscribe(data => {
      this.listaDisponibilidade = data;
    })
  }

  onChangeCombinar() {
    this.listaDisponibilidade.map((item: any) => {
      item['selected'] = false;
    })
    this.dataInicioToSend = null;
    this.dataFimToSend = null;
    this.qtdHorasCombinar = '';
    this.availabilityId = undefined;
  }

  selecionarDataHorario(item: any) {
    if (!item.scheduled) {
      this.combinar = false;
      this.listaDisponibilidade.map((item: any) => {
        item['selected'] = false;
      })
      this.availabilityId = item['id'];
      item['selected'] = true;

      this.dataInicioToSend = item.startDate;
      this.dataFimToSend = item.endDate;

    } else {
      swal.fire('', 'Horário já reservado', 'warning')
    }
  }

}
