import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { environment } from 'src/environments/environment';
import { BehaviorSubject, Observable } from 'rxjs';
import { User } from 'stream-chat';

@Injectable({ providedIn: 'root' })
export class AuthenticationService {
  private userSubject = new BehaviorSubject<any>({});
  user$ = this.userSubject.asObservable();

  constructor(private http: HttpClient) {
    const user = this.getUserSession();
    if (user) {
      this.userSubject.next(user);
    }
  }

  login(model: any) {
    return this.http.post(environment.URLS.API_BASE_URL + "/auth/login", model);
  }

  forgotPassword(model: any): Observable<any>  {
    return this.http.post(environment.URLS.API_BASE_URL + "/auth/forgot-password", model);
  }

  validateToken(model: any): Observable<any>  {
    return this.http.post(environment.URLS.API_BASE_URL + "/auth/validate-token", model);
  }

  refinePassword(model: any): Observable<any>  {
    return this.http.put(environment.URLS.API_BASE_URL + "/auth/redefine-password/" + model['userId'], model);
  }

  createUser(model: any): Observable<any>  {
    return this.http.post(environment.URLS.API_BASE_URL + "/users", model);
  }

  changePassword(userId: string, model: any): Observable<any> {
    return this.http.put(`${environment.URLS.API_BASE_URL}/users/${userId}/password`, model)
  }

  getUserSession(): any {
    return JSON.parse(localStorage.getItem('user') as string);
  }

  updateUserSession(user: any) {
    this.userSubject.next(user);
    localStorage.setItem('user', JSON.stringify(user));
  }

  logout() {
    const userId = this.getUserSession()['id']
    localStorage.removeItem('user');
    return this.http.post(environment.URLS.API_BASE_URL + "/auth/logout/" + userId, {});
  }
}
