
import { Injectable } from '@angular/core';
import { ChannelService, ChatClientService } from 'stream-chat-angular';
import { AuthenticationService } from '../auth/authentication.service';
import { environment } from 'src/environments/environment';


@Injectable({
  providedIn: 'root'
})
export class ChatService {
  private user: any;

  constructor(
    private chatService: ChatClientService,
    private channelService: ChannelService,
    private authenticationService: AuthenticationService,
  ) {
    this.authenticationService.user$.subscribe(user => {
      this.user = user;
    })

    this.chatService.init(environment.STREAM_API_KEY, this.user?.id, this.user?.token);
  }

  async newChannel(mentorName: string, mentorId: string) {

    const channelName = `${this.user.name}-${mentorName}`;
    const channelOptions = {
      members: [this.user?.id, mentorId],
      name: channelName,
      image: `https://getstream.io/random_svg/?id=cool-surf-0&name=${this.user.name}+${mentorName}`
    };

    const channel = this.chatService.chatClient.channel('messaging', channelOptions);

    if(channel.initialized === true) return;

    const response = await channel.create();
  }


  async getChannels(channelName?: string){
    await this.channelService.init({ type: 'messaging', members: {$in: [this.user?.id]} });
  }
}
