import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { environment } from 'src/environments/environment';

@Injectable({ providedIn: 'root' })
export class UserService {

  mentorRequestSession: any;
  profileId: string = '';

  constructor(private http: HttpClient) {}

  // *==== GET ====*
  getUsers(): Observable<any> {
    return this.http.get(environment.URLS.API_BASE_URL + '/users')
  }

  getMentors(): Observable<any> {
    return this.http.get(`${environment.URLS.API_BASE_URL}/users/mentors`)
  }

  getAdmins(): Observable<any> {
    return this.http.get(environment.URLS.API_BASE_URL + '/users/admins')
  }

  getUserById(id: string): Observable<any> {
    return this.http.get(environment.URLS.API_BASE_URL + '/users/' + id)
  }

  getUserByIdToMentorView(id: string): Observable<any> {
    return this.http.get(`${environment.URLS.API_BASE_URL}/users/${id}/mentor-view`)
  }

  getSessionsByUserId(userId: string): Observable<any> {
    return this.http.get(`${environment.URLS.API_BASE_URL}/sessions/user/${userId}`)
  }

  getDashboardData(userId: string): Observable<any> {
    return this.http.get(`${environment.URLS.API_BASE_URL}/dashboard/${userId}`)
  }

  getMentorHomePage(userId: string): Observable<any> {
    return this.http.get(`${environment.URLS.API_BASE_URL}/users/${userId}/home`)
  }

  getAdminReportsData(): Observable<any> {
    return this.http.get(`${environment.URLS.API_BASE_URL}/admin-reports`)
  }

  getOverviewMetrics(): Observable<any> {
    return this.http.get(`${environment.URLS.API_BASE_URL}/admin-reports/overview-metrics`)
  }

  // *==== PUT ====*
  putUser(id: string, model: any): Observable<any> {
    return this.http.put(environment.URLS.API_BASE_URL + '/users/' + id, model)
  }

  putAvatar(id: string, model: any): Observable<any> {
    const formData = new FormData();
    formData.append('file', model.avatar);

    return this.http.put(`${environment.URLS.API_BASE_URL}/users/${id}/avatar`, formData);
  }

  // *==== POST ====*
  reviewMentor(userId: string, body: any) {
    return this.http.post(`${environment.URLS.API_BASE_URL}/users/${userId}/review`, body);
  }

  banUser(userId: string, body: any) {
    return this.http.post(`${environment.URLS.API_BASE_URL}/users/${userId}/ban`, body);
  }

  acceptSession(sessionId: string): Observable<any> {
    return this.http.put(`${environment.URLS.API_BASE_URL}/sessions/${sessionId}/accept`, {});
  }

  declineSession(sessionId: string): Observable<any> {
    return this.http.put(`${environment.URLS.API_BASE_URL}/sessions/${sessionId}/decline`, {});
  }

  cancelSession(sessionId: string, model: any): Observable<any> {
    return this.http.put(`${environment.URLS.API_BASE_URL}/sessions/${sessionId}/cancel`, model);
  }

  getUserExperiences(userId: string) {
    return this.http.get(`${environment.URLS.API_BASE_URL}/experiences/${userId}`)
  }

  postUserExperience(userId: string, model: any) {
    return this.http.post(`${environment.URLS.API_BASE_URL}/experiences`, model)
  }

  putUserExperience(userId: string, experienceId: string, model: any) {
    return this.http.put(`${environment.URLS.API_BASE_URL}/experiences/${userId}/${experienceId}`, model)
  }

  deleteUserExperience(userId: string, experienceId: string) {
    return this.http.delete(`${environment.URLS.API_BASE_URL}/experiences/${userId}/${experienceId}`)
  }


  getUserSocialMedia(userId: string) {
    return this.http.get(`${environment.URLS.API_BASE_URL}/social-medias/${userId}`)
  }

  postUserSocialMedia(model: any) {
    return this.http.post(`${environment.URLS.API_BASE_URL}/social-medias`, model)
  }

  putUserSocialMedia(socialMediaID: string, model: any) {
    return this.http.put(`${environment.URLS.API_BASE_URL}/social-medias/${socialMediaID}`, model)
  }

  deleteUserSocialMedia(socialMediaID: string) {
    return this.http.delete(`${environment.URLS.API_BASE_URL}/social-medias/${socialMediaID}`)
  }

}
