export type User = {
  id: string;
  name: string;
  email: string;
  abstract: string;
  avatar: string;
  isAdmin: string;
  description: string;
  experiences: Experience[];
  socialMedias: SocialMedias[];
  reviewToMentor: Review[];
  userTopics: UserTopic[];
  skills: string[];
  cpf: string;
  password: string;
  score?: number;
}

export type Review = {
  id: string;
  grade: number;
  student: Partial<User>;
  evaluation: string;
  createdAt: string;
}
export type SocialMedias = {
  url: string;
  type: string;
}

export type UserTopic = {
  topic: Topic;
}

export type Topic = {
  name: string;
  active: boolean;
}

export type Experience = {
  title: string;
  description: string;
  role: string;
  company: string;
  startDate: string;
  endDate: string;
}

export type Session =  {
  id: string;
  startDate: string;
  endDate: string;
  status: string;
  description: string;
  totalValue: number;
  cancelledReason: string;
  // userTopic: UserTopic
  // student: User
  // mentor: User
  // availability: Availability
  // paymentTransactions: [PaymentTransaction!]
  createdAt: string;
  updatedAt: string;
}

export type SessionPayload =  {
  id: string;
  startDate: string;
  endDate: string;
  status: SessionStatus;
  description: string;
  totalValue: number;
  cancelledReason: string;
  avatar: string;
  name: string;
  asMentor: boolean;
  studentOrMentorId: string;
  createdAt: string;
  collapsed?: boolean;
  userTopic: UserTopic;
  mentorId?: string;
  studentId?: string;
}

export type Availability = {
  startDate: string;
  endDate: string;
  weekDay: string;
}

export enum SessionStatus {
  PENDING = 'pending',
  CONFIRMED = 'confirmed',
  CANCELLED = 'cancelled',
  COMPLETED = 'completed',
  DECLINED = 'declined',
}
